@@ -203,7 +203,7 @@ def _start(client, bot):
 				except:
 					pass
 		return emb
-	def get_vars(line, guild, vars):
+	def get_vars(line, guild, vars, author):
 		nowloop=""
 		while "$getLocalVar"+bot._style[0] in line:
 			if nowloop==line:
@@ -216,25 +216,40 @@ def _start(client, bot):
 				break
 			else:
 				nowloop=line
-				line=line.replace("$getVar"+bot._style[0]+line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],bot._db.get("global",line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0].split(qbot._separator)[0],line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]))
+				try:
+					line=line.replace("$getVar"+bot._style[0]+line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],bot._db.get("global",line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0].split(qbot._separator)[0],line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]))
+				except:
+					try:
+						line=line.replace("$getVar"+bot._style[0]+line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],bot._db.get("global",line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0].split(qbot._separator)[0],str(author.id)))
+					except:
+						break
 		while "$getServerVar"+bot._style[0] in line:
 			if nowloop==line:
 				break
 			else:
 				nowloop=line
-				line=line.replace("$getServerVar"+bot._style[0]+line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],bot._db.get("server",line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0],line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]))
+				try:
+					line=line.replace("$getServerVar"+bot._style[0]+line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],bot._db.get("server",line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0],line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]))
+				except:
+					try:
+						line=line.replace("$getServerVar"+bot._style[0]+line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],bot._db.get("server",line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0],str(guild.id)))
+					except:
+						break
 		while "$getUserVar"+bot._style[0] in line:
 			if nowloop==line:
 				break
 			else:
 				nowloop=line
 				try:
-					line=line.replace("$getUserVar"+bot._style[0]+line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],bot._db.get("user",line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0],line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1], str(guild.id)))
+					line=line.replace("$getUserVar"+bot._style[0]+line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],bot._db.get("user",line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0],line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1], line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[2]))
 				except:
 					try:
-						line=line.replace("$getUserVar"+bot._style[0]+line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],bot._db.get("user",line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0],line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1], line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[2]))
+						line=line.replace("$getUserVar"+bot._style[0]+line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],bot._db.get("user",line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0],line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1], str(guild.id)))
 					except:
-						break
+						try:
+							line=line.replace("$getUserVar"+bot._style[0]+line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],bot._db.get("user",line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0],str(author.id), str(guild.id)))
+						except:
+							break
 		return line
 	async def replaces(line, message, guild, content, msg, vars, timerep, author):
 		nowloop=""
@@ -475,6 +490,27 @@ def _start(client, bot):
 					line=line.replace("$avatar"+bot._style[0]+line.split("$avatar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],str(user.avatar_url))
 				except Exception as e:
 					line=line.replace("$avatar"+bot._style[0]+line.split("$avatar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],"none")
+		while "$roleColor"+bot._style[0] in line:
+			if nowloop==line:
+				break
+			else:
+				nowloop=line
+				try:
+					role = discord.utils.get(guild.roles, id=int(line.split("$roleColor"+bot._style[0])[-1].split(bot._style[1])[0]))
+					line=line.replace("$roleColor"+bot._style[0]+line.split("$roleColor"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],str(role.color).lstrip("#").upper())
+				except Exception as e:
+					line=line.replace("$roleColor"+bot._style[0]+line.split("$roleColor"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],"none")
+		while "$toRGB"+bot._style[0] in line:
+			if nowloop==line:
+				break
+			else:
+				nowloop=line
+				try:
+					rgb=list(int(line.split("$toRGB"+bot._style[0])[-1].split(bot._style[1])[0][i:i+2], 16) for i in (0, 2, 4))
+					line=line.replace("$toRGB"+bot._style[0]+line.split("$toRGB"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],str(rgb[0])+","+str(rgb[1])+","+str(rgb[2]))
+				except Exception as e:
+					print(e)
+					line=line.replace("$toRGB"+bot._style[0]+line.split("$toRGB"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],"none")
 		while "$emojiUrl"+bot._style[0] in line:
 			if nowloop==line:
 				break
@@ -485,7 +521,7 @@ def _start(client, bot):
 					line=line.replace("$emojiUrl"+bot._style[0]+line.split("$emojiUrl"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],str(emoji.url))
 				except Exception as e:
 					line=line.replace("$emojiUrl"+bot._style[0]+line.split("$emojiUrl"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],"none")
-		line=get_vars(line, guild, vars)
+		line=get_vars(line, guild, vars, author)
 		while "$replaceText"+bot._style[0] in line:
 			if nowloop==line:
 				break
@@ -925,14 +961,20 @@ def _start(client, bot):
 								line=line[:-1]
 								line=await replaces(line, message, guild, content, msg, vars, timerep, author)
 								line=line.split(bot._separator)
-								bot._db.set("server",line[0],line[1],line[2])
+								try:
+									bot._db.set("server",line[0],line[1],line[2])
+								except:
+									bot._db.set("server",line[0],line[1],str(guild.id))
 						elif line.startswith("$setVar"+bot._style[0]):
 							if line[-1]==bot._style[1]:
 								line=line[len("$setVar"+bot._style[0]):]
 								line=line[:-1]
 								line=await replaces(line, message, guild, content, msg, vars, timerep, author)
 								line=line.split(bot._separator)
-								bot._db.set("global",line[0],line[1],line[2])
+								try:
+									bot._db.set("global",line[0],line[1],line[2])
+								except:
+									bot._db.set("global",line[0],line[1],str(author.id))
 						elif line.startswith("$setLocalVar"+bot._style[0]):
 							if line[-1]==bot._style[1]:
 								line=line[len("$setLocalVar"+bot._style[0]):]
@@ -970,9 +1012,12 @@ def _start(client, bot):
 								line=await replaces(line, message, guild, content, msg, vars, timerep, author)
 								line=line.split(bot._separator)
 								try:
-									bot._db.set("user",line[0],line[1],line[2],guild.id)
-								except:
 									bot._db.set("user",line[0],line[1],line[2],line[3])
+								except:
+									try:
+										bot._db.set("user",line[0],line[1],line[2],str(guild.id))
+									except:
+										bot._db.set("user",line[0],line[1],str(author.id),str(guild.id))
 						elif line.startswith("$addReactions"+bot._style[0]):
 							if line[-1]==bot._style[1]:
 								line=line[len("$addReactions"+bot._style[0]):]
@@ -1260,8 +1305,8 @@ def _start(client, bot):
 			def remember(text):
 				bot._nowcmd=text
 				return True
-			if any([message.content[:len(max(bot._cmds, key=len))].startswith(bot._codes["command"][cmd]["prefix"]+bot._codes["command"][cmd]["name"]) and remember(cmd) for cmd in bot._codes["command"]]):
-				await use(message, bot._nowcmd, bot._codes["command"][bot._nowcmd]["prefix"]+bot._codes["command"][bot._nowcmd]["name"], "command")
+			if any(message.content.startswith(get_vars(bot._codes["command"][cmd]["prefix"], message.guild, {}, message.author)+get_vars(bot._codes["command"][cmd]["name"], message.guild, {}, message.author)) and remember(cmd) for cmd in bot._codes["command"]):
+				await use(message, bot._nowcmd, get_vars(bot._codes["command"][bot._nowcmd]["prefix"], message.guild, {}, message.author)+get_vars(bot._codes["command"][bot._nowcmd]["name"], message.guild, {}, message.author), "command")
 	if bot._self:
 		client.run(bot._token, bot=False)
 	else:
